@@ -23,6 +23,10 @@
 #' Transform response content to data.table.
 #' @param keep_bad_request Optional.\cr
 #' Keep Bad Request to avoid breaking a workflow, especially meaningful in a batch request
+#' @param max_core Optional.\cr
+#' A threshold of max cores for parallel operation. There is no need to set a `max_core` generally.
+#' But for some extreme high performance case, like `AMD Threadripper` and `Intel Xeon`,
+#' super multiple-core CPU will meet the limitation of queries per second.
 #'
 #' @return
 #' Returns a JSON, XML or data.table of results containing detailed geocode information. See \url{https://lbs.amap.com/api/webservice/guide/api/convert} for more information.
@@ -50,10 +54,11 @@ convertCoord <-
     sig = NULL,
     output = NULL,
     to_table = TRUE,
-    keep_bad_request = TRUE
+    keep_bad_request = TRUE,
+    max_core = NULL
   ){
     if (length(locations) == 1) {
-      # if there is one address, use getCoord.individual directly
+      # if there is one address, use convertCoord.individual directly
       convertCoord.individual(
         locations = locations,
         key = key,
@@ -64,9 +69,12 @@ convertCoord <-
         keep_bad_request = keep_bad_request
       )
     } else {
-      # if there is multiple addresses, use getCoord.individual by laapply
+      # Create local parallel cluster
+      cluster <- parallel_cluster_maker(max_core = max_core)
+      # if there is multiple addresses, use convertCoord.individual by parLapply
       ls_queries <-
-        lapply(
+        parallel::parLapply(
+          cl = cluster,
           locations,
           convertCoord.individual,
           key = key,
@@ -76,6 +84,8 @@ convertCoord <-
           to_table = to_table,
           keep_bad_request = keep_bad_request
         )
+      # stop cluster
+      parallel::stopCluster(cluster)
       # detect return list of raw requests or `rbindlist` parsed data.table
       if (isTRUE(to_table)) {
         return(data.table::rbindlist(ls_queries))
@@ -124,7 +134,8 @@ convertCoord.individual <- function(
     if (is.null(getOption('amap_key'))) {
       stop(
         'Please set key argument or set amap_key globally by this command
-                 options(amap_key = your key)'
+                 options(amap_key = your key)',
+        call. = FALSE
       )
     }
     key = getOption('amap_key')
@@ -216,7 +227,8 @@ extractConvertCoord <- function(res) {
   # If request_stat is failure
   # Return the failure information
   if(request_stat == '0'){
-    stop(res$info)
+    stop(res$info,
+         call. = FALSE)
   }
 
   # parse lng and lat from location
