@@ -24,6 +24,11 @@
 #' Transform response content to data.table.
 #' @param keep_bad_request Optional.\cr
 #' Keep Bad Request to avoid breaking a workflow, especially meaningful in a batch request
+#' @param max_core Optional.\cr
+#' A threshold of max cores for parallel operation. There is no need to set a `max_core` generally.
+#' But for some extreme high performance case, like `AMD Threadripper` and `Intel Xeon`,
+#' super multiple-core CPU will meet the limitation of queries per second.
+#'
 #' @return
 #' Returns a JSON, XML or data.table of results containing detailed geocode information. See \url{https://lbs.amap.com/api/webservice/guide/api/georegeo} for more information.
 #' @export
@@ -54,7 +59,8 @@ getCoord <-
            output = NULL,
            callback = NULL,
            to_table = TRUE,
-           keep_bad_request = TRUE) {
+           keep_bad_request = TRUE,
+           max_core = NULL) {
     if (length(address) == 1) {
       # if there is one address, use getCoord.individual directly
       getCoord.individual(
@@ -68,9 +74,12 @@ getCoord <-
         keep_bad_request = keep_bad_request
       )
     } else {
-      # if there is multiple addresses, use getCoord.individual by laapply
+      # Create local parallel cluster
+      cluster <- parallel_cluster_maker(max_core = max_core)
+      # if there is multiple addresses, use getCoord.individual by parLapply
       ls_queries <-
-        lapply(
+        parallel::parLapply(
+          cl = cluster,
           address,
           getCoord.individual,
           key = key,
@@ -81,6 +90,8 @@ getCoord <-
           to_table = to_table,
           keep_bad_request = keep_bad_request
         )
+      # stop cluster
+      parallel::stopCluster(cluster)
       # detect return list of raw requests or `rbindlist` parsed data.table
       if (isTRUE(to_table)) {
         return(data.table::rbindlist(ls_queries))
@@ -134,7 +145,8 @@ getCoord.individual <-
       if (is.null(getOption('amap_key'))) {
         stop(
           'Please set key argument or set amap_key globally by this command
-             options(amap_key = your key)'
+             options(amap_key = your key)',
+          call. = FALSE
         )
       }
       key = getOption('amap_key')
@@ -236,7 +248,8 @@ extractCoord <- function(res) {
 
     # detect whether request succeed or not
     if (res$status != 1) {
-      stop(res$info)
+      stop(res$info,
+           call. = FALSE)
     }
 
     # detect thee number of response
