@@ -1,7 +1,7 @@
 # Test whether convertCoord can retrun right class
 test_that('Reuturn detailed tibble with correct location', {
   skip_if(is.null(getOption('amap_key')))
-  res <- convertCoord('116.481499,39.990475')
+  res <- convertCoord(c('116.481499,39.990475', '116.481499,49.990475'))
   lng_class <-
     class(res$lng)
   lng_is_na <-
