@@ -29,3 +29,13 @@ test_that('Reuturn NA tibble with wrong location', {
   expect_equal(any(stringr::str_detect(res_class, 'tbl_df')),  TRUE)
   expect_equal(all(is.na(res)), TRUE)
 })
+
+# Test parallel request
+test_that('Test parallel request', {
+  skip_if(is.null(getOption('amap_key')))
+  add_ls <- rep_len(x = '成都中医药大学', length.out = 200)
+  res <- getCoord(add_ls, max_core = 4)
+  unique_res <-
+    unique(res)
+  expect_equal(unique_res$province,  '四川省')
+})
