@@ -29,3 +29,13 @@ test_that('Reuturn na tibble with correct coordinate', {
   expect_equal(any(stringr::str_detect(res_class, 'tbl_df')),  TRUE)
   expect_equal(all(is.na(res)), TRUE)
 })
+
+test_that('Test parallel request', {
+  skip_if(is.null(getOption('amap_key')))
+  lng_ls <- rep_len(x = 104, length.out = 100)
+  lat_ls <- rep_len(x = 30, length.out = 100)
+  res <- getLocation(lng = lng_ls, lat = lat_ls, max_core = 12)
+  unique_res <-
+    unique(res)
+  expect_equal(unique_res$province,  '四川省')
+})
